@@ -1,9 +1,9 @@
 import matplotlib.pyplot as plt
 
 
-def tigran_plot(Ox, Oy):
+def get_plot(Ox, Oy):
     plt.plot(Ox, Oy)
     return plt.show()
 
 
-__version__ = "1.0.0"
+__version__ = "1.0.5"
